%% Program for calculating near-field heat transfer
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program is used to calculate the radiative heat transfer between two
% semi-infinite media that are isotropic and nonmagnetic
% Related material properties of these two plates including Frensnal coefficients, 
% and s function are evaluated in funtion s(w, d, Betas, evan) <s.m>
% Integration function Simpson.m based on Simpson's rule
% 1--source; 2--receiver; 3--vacuum
% Developed by Professor Zhuomin Zhang's group at Georgia Tech
% References [1] Zhang, Nano/Microscale Heat Transfer (2007), McGraw-Hill, NY
% Ref: Fu and Zhang, Int. J. Heat Mass Transfer (2006) 49, 1703-1718
% Ref: Basu and Zhang, J. Appl. Phys. (2009) 105, 093535
% Ref: Wang, Basu and Zhang, J. Phys. D Appl. Phys. (2009) 42, 245403
% Last modified by Xianglei Liu (October 2014)
% Please direct your questions to Mr. Xianglei Liu: xliu319@gatech.edu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%need to call function simpson_p and simpson_e
clear all
clc
tic

% Physical parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h = 1.054571596e-34;           %Planck's constant over 2*pi
global c0;
c0 = 2.99792458e+8;            %speed of light in vacuum
kb = 1.3806503e-23;
qe = 1.602176462e-19;          %elementary electric charge %%for doped silicon calculation
e0 = 8.854187817e-12;          %electric permittivity %% for doped silicon calculation
T1 = 300;                      %temperature of the source
T2 = 299;                      %temperature of the receiver
dc = 0.5e-9;                 %interatomic space
beta_max = pi/dc;              %the upper limit for beta[kz] space
darray = [1e-8, 1e-7, 1e-6];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initiaization of different parameters
 w1 = 2e12;                                
 w2 = 2e15;
 dw = 2e12;   %frequency interval
 nw = floor((w2-w1)/dw+1); %total number of frequency points
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%calculation of total energy flux 
for j = 1:length(darray)
         d=darray(j);
         index=0;
      for w=w1:dw:w2;
         %dielectric function
            ep1=Lorentz_SiC(w);
            ep2=Lorentz_SiC(w);
	   % ep1=epsilon_Au(w);
           % ep2=epsilon_Au(w);
%------------------------------------------
% Calculating the radiative heat transfer
%------------------------------------------
             index = index+1;
             a0 = 0;
             a1 = (w-10)/c0;    %a0 and a1 for the integration of propagating waves. 
             nkp = 1000;
             errp = 0.01;
% In order to avoid singularity we take it at w-10
             ae1 = (w+10)/c0;     %integration limit of evanescient waves
             ae2 = 8*w/c0; 
             ae3 = 100*w/c0;
             ae4 = beta_max;
             nke0 = 1000;
             nke1 = 1000;     
             nke2 = 1000;
             erre0 = 1.0;
             erre1 = 0.01;
             erre2 = 0.1;
             Q1=h*w/(exp(h*w/(kb*T1))-1);    %% Planck Oscillator
             Q2=h*w/(exp(h*w/(kb*T2))-1);
             val_p = simpson_p(w, nkp, d, a0, a1, ep1, ep2, errp);
                   fluxp=val_p*(Q1-Q2);
             val_e0= simpson_e(w, nke0, d, ae1, ae2, ep1, ep2, erre0);
                   fluxe0=val_e0*(Q1-Q2);
             val_e1= simpson_e(w, nke1, d, ae2, ae3, ep1, ep2, erre1);
                   fluxe1=val_e1*(Q1-Q2);
             val_e2= simpson_e(w, nke2, d, ae3, ae4, ep1, ep2, erre2);
                   fluxe2=val_e2*(Q1-Q2);
             flux(index)=fluxp+fluxe0+fluxe1+fluxe2;
      end
  
      Q_t(j)=(flux(1)+4*sum(flux(2:2:(nw-1)))+2*sum(flux(3:2:(nw-2)))+flux(nw))*dw/3;

% flux gives the spectral distribution, while Q_t gives the net heat transfer for different distances

end
toc
