%% Program for calculating near-field heat transfer between semi-infinite uniaxials
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program is used to calculate the radiative heat transfer between two semi-infinite uniaixal plates
% Developed by Professor Zhuomin Zhang's group at Georgia Tech
% For details, please refer to Liu et al. (2014) Int. J. Heat and Mass Transfer 73, 389-398
% Also, Liu et al. (2013), Appl. Phys. Lett. 103 (21), 213102
% Last modified by Xianglei Liu (October 2014)
% Please direct your questions to Mr. Xianglei Liu: xliu319@gatech.edu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
clc
tic

% Physical parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h = 1.054571596e-34;           %Planck's constant over 2*pi
c0 = 2.99792458e+8;            %speed of light in vacuum
kb = 1.3806503e-23;
qe = 1.602176462e-19;          %elementary electric charge %%for doped silicon calculation
e0 = 8.854187817e-12;          %electric permittivity %% for doped silicon calculation
%@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
T1 = 300;                      %temperature of the emitter  @@@@@@@@
T2 = 299;                      %temperature of the receiver@@@@@@@@
d = 100*1e-9;   %gap spacing
f1 = 0.03;   %filling ratio for the emitter (if f = 1, it becomes bulk)
f2 = f1;    %filling ratio for the emitter

%@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 %used for uniaxial medium using effective medium theory
g_e=0.0;
g_o=0.5;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initiaization of different parameters
w1=2.0e12; %rad/s about 940 um in wavelength
w2=2.0e15; %rad/s about 0.94 um in wavelength
dw=2.0e12;
nw=floor((w2-w1)/dw+1)  %1001 2001
             a0 = 0;
             nk = 1001; %It should be sufficiently large to obtain good accuracy
             const1 = 3;
	     const2 = 6;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%calculation of total energy flux 
      for ii=1:nw
             w(ii)=w1+(ii-1)*dw;
             %dielectric function
             epsi1=Lorentz_SiC(w(ii));%for emitter
             epsi2=epsi1;%for receiver
 %the following is an example for nanowire, air is the host, f is filling ratio of SiC  @@@@@@@@@@@@    
 %for other structures such as multilayers, nanoholes, or details, please refer to the references @@@@
 %epsi_O1 and epsi_E1 are the ordinary and extraordinary dielecric functions for emitter
             epsi_O1=1+f1*(epsi1-1)/(1+g_o*(1-f1)*(epsi1-1));
             epsi_E1=1+f1*(epsi1-1)/(1+g_e*(1-f1)*(epsi1-1));  
             epsi_O2=1+f2*(epsi2-1)/(1+g_o*(1-f2)*(epsi2-1));
             epsi_E2=1+f2*(epsi2-1)/(1+g_e*(1-f2)*(epsi2-1));            
             %------------------------------------------
% Calculating the radiative heat transfer
%------------------------------------------
             a1 = (w(ii)-10)/c0;    %a0 and a1 for the integration of propagating waves. 
             ae1 = (w(ii)+10)/c0;     %integration limit of evanescient waves
             ae2 = max(0.6/d,const1*w(ii)/c0); 
             ae3 = max(5/d,const2*w(ii)/c0);
             
             Q1(ii)=h*w(ii)/(exp(h*w(ii)/(kb*T1))-1);    %% Planck Oscillator
             Q2(ii)=h*w(ii)/(exp(h*w(ii)/(kb*T2))-1);
             [T_w_p] = Uni_spec(w(ii), nk, d, a0, a1, epsi_O1, epsi_E1, epsi_O2, epsi_E2);
             [T_w_e1]= Uni_spec(w(ii), nk, d, ae1, ae2, epsi_O1, epsi_E1, epsi_O2, epsi_E2);
             [T_w_e2]= Uni_spec(w(ii), nk, d, ae2, ae3, epsi_O1, epsi_E1, epsi_O2, epsi_E2);
             S_w(ii) = (T_w_p+T_w_e1+T_w_e2)*(Q1(ii)-Q2(ii));

%Note: S_w gives an array of the spectral heat flux@@@@@@@@@@@@@
    
        end
  
            Q_t=(S_w(1)+4*sum(S_w(2:2:(nw-1)))+2*sum(S_w(3:2:(nw-2)))+S_w(nw))*dw/3;

%Note: Q_t is the net radiative heat transfer (simpson's rule is used in the integration)@@@@@@@@@

figure (1)
plot(w,S_w,'g','linewidth',2)
hold on
toc




