%Integration based on the simpson rule and convergence criteria

function [Int_val] = simpson_e(w, n, d, min, max, ep_1, ep_2, err)
%used to caluclate heat flux for evanescent waves
         n1 = n;
         [s_e,dkx] = func_e(w, n1, d, min, max, ep_1, ep_2);
         temp1=(s_e(1)+4*sum(s_e(2:2:n1))+2*sum(s_e(3:2:n1-1))+s_e(n1+1))*dkx/3;
         
         if(temp1<=1e-50)
               temp2 = 0;
         else
               n1 = n1*2;
               [s_e,dkx] = func_e(w, n1, d, min, max, ep_1, ep_2);            
               temp2=(s_e(1)+4*sum(s_e(2:2:n1))+2*sum(s_e(3:2:n1-1))+s_e(n1+1))*dkx/3;
             while ((abs(temp2-temp1)/temp2) >= err)
                    temp1 = temp2;
                    n1 = n1*2;
                    [s_e,dkx] = func_e(w, n1, d, min, max, ep_1, ep_2);
                    temp2=(s_e(1)+4*sum(s_e(2:2:n1))+2*sum(s_e(3:2:n1-1))+s_e(n1+1))*dkx/3;
             end
         end
                Int_val = temp2;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% s funtion divided by pi^2 in beta(kz) space for evanescent waves
% 1--source; 2--receiver; 3--vacuum
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [s_e,dkx] = func_e(w, n, d, min, max, ep_1, ep_2)
  %spectral and wavevector dependent heat flux, evanascent modes          
            
global c0
dkx = (max-min)/n;                                         
kx = zeros(n+1,1);        %horizontal component of wavevector k
s_e = zeros(n+1,1);

for ind=1:n+1
    kx(ind)= min+(ind-1)*dkx;
  %  vertical component of wavevector k
   	kz1 = sqrt(ep_1*w*w/(c0*c0)-kx(ind)^2); 
   	kz2 = sqrt(ep_2*w*w/(c0*c0)-kx(ind)^2); 
   	kz3 = sqrt(w*w/(c0*c0)-kx(ind)^2);     
  %  frensnel coefficients
   	rs31 = ((kz3-kz1)/(kz3+kz1));                  %s-polarization interface between 1 and 3
   	rp31 = ((ep_1*kz3-kz1)/(ep_1*kz3+kz1));        %p-polarization interface between 1 and 3
    rs32 = ((kz3-kz2)/(kz3+kz2));                  %s-polarization interface between 2 and 3
   	rp32 = ((ep_2*kz3-kz2)/(ep_2*kz3+kz2));        %p-polarization interface between 2 and 3
  %  s function 
   	e_temp = exp(-2*imag(kz3)*d);
    s_e(ind) = kx(ind)*e_temp*(imag(rs31)*imag(rs32)/(abs(1-rs31*rs32*e_temp))^2+imag(rp31)*imag(rp32)/(abs(1-rp31*rp32*e_temp))^2)/(pi*pi);
end      
