%Integration based on the simpson rule and convergence criteria

function [Int_val] = simpson_p(w, n, d, min, max, ep_1, ep_2, err)
%used to calculate heat flux for propogating modes

         n1 = n;                                               
         [s_p,dkx] = func_p(w, n1, d, min, max, ep_1, ep_2);        
         temp1=(s_p(1)+4*sum(s_p(2:2:n1))+2*sum(s_p(3:2:n1-1))+s_p(n1+1))*dkx/3;

            if(temp1<=1e-50)
                temp2 = 0;
            else
                n1 = n1*2;
                [s_p,dkx] = func_p(w, n1, d, min, max, ep_1, ep_2);        
                temp2=(s_p(1)+4*sum(s_p(2:2:n1))+2*sum(s_p(3:2:n1-1))+s_p(n1+1))*dkx/3;
                while ((abs(temp2-temp1)/temp2) >= err)
                    temp1 = temp2;
                    n1 = n1*2;
                    [s_p,dkx] = func_p(w, n1, d, min, max, ep_1, ep_2);        
                    temp2=(s_p(1)+4*sum(s_p(2:2:n1))+2*sum(s_p(3:2:n1-1))+s_p(n1+1))*dkx/3;
                end
            end
                Int_val = temp2;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% s funtion divided by pi^2 in beta(kz) space for propagation waves
% 1--source; 2--receiver; 3--vacuum
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [s_p,dkx] = func_p(w, n, d, min, max, ep_1, ep_2)
 %spectral and wavevector dependent heat flux, propogating modes           
            
global c0
dkx = (max-min)/n;                                         
kx = zeros(n+1,1);        %horizontal component of wavevector k
s_p = zeros(n+1,1);

for ind=1:n+1
    kx(ind)= min+(ind-1)*dkx;
  %  vertical component of wavevector k
   	kz1 = sqrt(ep_1*w*w/(c0*c0)-kx(ind)^2); 
   	kz2 = sqrt(ep_2*w*w/(c0*c0)-kx(ind)^2); 
   	kz3 = sqrt(w*w/(c0*c0)-kx(ind)^2);    %vacuum gap 
  %  frensnel coefficients
   	rs31 = ((kz3-kz1)/(kz3+kz1));                  %s-polarization interface between 1 and 3
   	rp31 = ((ep_1*kz3-kz1)/(ep_1*kz3+kz1));        %p-polarization interface between 1 and 3
    rs32 = ((kz3-kz2)/(kz3+kz2));                  %s-polarization interface between 2 and 3
   	rp32 = ((ep_2*kz3-kz2)/(ep_2*kz3+kz2));        %p-polarization interface between 2 and 3
  %  s function 
    tps_temp = abs(1-rs31*rs32*exp(2*i*kz3*d));
   	tpp_temp = abs(1-rp31*rp32*exp(2*i*kz3*d));
    s_p(ind) = kx(ind)*((1-abs(rs31)^2)*(1-abs(rs32)^2)/tps_temp^2+(1-abs(rp31)^2)*(1-abs(rp32)^2)/(tpp_temp^2))/(4*pi*pi);
end      

